@@ -31,18 +31,43 @@ func (line *Line) HighlightedTokens(plainTextStyle twin.Style, standoutStyle *tw
 	plain := line.Plain(lineIndex)
 	matchRanges := getMatchRanges(&plain, search)
 
+	var searchHitStyle twin.Style
+	if standoutStyle != nil {
+		searchHitStyle = *standoutStyle
+	} else {
+		searchHitStyle = plainTextStyle.WithAttr(twin.AttrReverse)
+	}
+
+	var lineHighlightBackground *twin.Color
+	if !matchRanges.Empty() {
+		// Figure out a line background that lies between plainTextStyle and searchHitStyle
+		plainBg := plainTextStyle.Background()
+		if plainTextStyle.HasAttr(twin.AttrReverse) {
+			plainBg = plainTextStyle.Foreground()
+		}
+		hitBg := searchHitStyle.Background()
+		if searchHitStyle.HasAttr(twin.AttrReverse) {
+			hitBg = searchHitStyle.Foreground()
+		}
+
+		if plainBg != twin.ColorDefault && hitBg != twin.ColorDefault {
+			// We have two real colors. Mix them! I got to "0.2" by testing some
+			// numbers. 0.2 is visible but not too strong.
+			mixed := plainBg.Mix(hitBg, 0.2)
+			lineHighlightBackground = &mixed
+		}
+	}
+
 	fromString := textstyles.StyledRunesFromString(plainTextStyle, line.raw, lineIndex)
 	returnRunes := make([]twin.StyledRune, 0, len(fromString.StyledRunes))
 	for _, token := range fromString.StyledRunes {
 		style := token.Style
 		if matchRanges.InRange(len(returnRunes)) {
-			if standoutStyle != nil {
-				style = *standoutStyle
-			} else {
-				style = style.WithAttr(twin.AttrReverse)
-				style = style.WithBackground(twin.ColorDefault)
-				style = style.WithForeground(twin.ColorDefault)
-			}
+			// Highlight the search hit
+			style = searchHitStyle
+		} else if !matchRanges.Empty() && lineHighlightBackground != nil {
+			// Highlight lines that have search hits
+			style = style.WithBackground(*lineHighlightBackground)
 		}
 
 		returnRunes = append(returnRunes, twin.StyledRune{
@@ -51,9 +76,15 @@ func (line *Line) HighlightedTokens(plainTextStyle twin.Style, standoutStyle *tw
 		})
 	}
 
+	trailer := fromString.Trailer
+	if !matchRanges.Empty() && lineHighlightBackground != nil {
+		// Highlight to the end of the line
+		trailer = plainTextStyle.WithBackground(*lineHighlightBackground)
+	}
+
 	return textstyles.StyledRunesWithTrailer{
 		StyledRunes: returnRunes,
-		Trailer:     fromString.Trailer,
+		Trailer:     trailer,
 	}
 }
 
